@@ -1,4 +1,4 @@
-# $Id: Get_nice.pm,v 1.8 2004/01/24 23:40:06 epaepa Exp $
+# $Id: Get_nice.pm,v 1.9 2004/03/30 19:41:11 epaepa Exp $
 #
 # Library to wrap LWP::Simple to put in a random delay between
 # requests and to set User-Agent.  We really should be using
@@ -13,6 +13,12 @@
 # XMLTV::Get_nice::get_nice_aux() is the one to cache with
 # XMLTV::Memoize or whatever.
 #
+# If you want to change what function is called to get pages, set
+# $XMLTV::Get_nice::get to a code reference that takes a URL and
+# returns a page.  Perhaps the right thing would be to decouple the
+# delay logic into a separate module, but at the moment fetching web
+# pages is the only use of it.
+#
 
 package XMLTV::Get_nice;
 use base 'Exporter';
@@ -22,6 +28,8 @@ use XMLTV;
 $ua->agent("xmltv/$XMLTV::VERSION");
 our $Delay = 5; # in seconds
 
+our $get = \&LWP::Simple::get;
+
 sub get_nice( $ ) {
     # This is to ensure scalar context, to work around weirdnesses
     # with Memoize (I just can't figure out how SCALAR_CACHE and
@@ -44,7 +52,7 @@ sub get_nice_aux( $ ) {
         sleep $sleep_time if $sleep_time > 0;
     }
 
-    my $r = LWP::Simple::get($url);
+    my $r = $get->($url);
 
     # At the moment download failures seem rare, so the script dies if
     # any page cannot be fetched.  We could later change this routine
